Steno
=====

An application that helps people learning a foreign language to train listening
skills.

Documentation
-------------

`The documentation <http://pythonhosted.org/steno/index.html>`_ constains more
detailed `description <http://pythonhosted.org/steno/description.html>`_,
`user manual <http://pythonhosted.org/steno/usermanual.html>`_ and other
information about the project.

Screenshots
-----------

You can find screenshots of the application in `the appropriate section <http://pythonhosted.org/steno/description.html#screenshots>`_
of the project documentation.

Getting started
---------------

The application has the following dependencies:

* wxPython
* pysrt
* google_translate_api

You can install the application using ``pip``

::

    pip install steno

or ``easy_install``:

::

    easy_install steno
    
Besides, you can obtain the source code from GitHub repository and use it:

::

    git clone git://github.com/antonkonyshev/steno.git
    cd steno && python setup.py install

If you want to know about other ways to install the application or other
possible operations, such as the compiling of a portable binary build using
PyInstaller or running without installation, please, read
`the "Installation" chapter <http://pythonhosted.org/steno/installation.html>`_
of the project documentation.